@@ -3,7 +3,7 @@
 
  Copyright (C) 2005-2006 by Pino Toscano, toscano.pino@tiscali.it
  Copyright (C) 2003-2006 by Carsten Niehaus, cniehaus@kde.org
- Copyright (C) 2007-2009 by Marcus D. Hanwell
+ Copyright (C) 2007-2009 by Marcus D. Hanwell, marcus@cryos.org
  Copyright (C) 2010 by Etienne Rebetez, etienne.rebetez@oberwallis.ch
 
  Kalzium is free software; you can redistribute it and/or modify
@@ -44,8 +44,8 @@ class PeriodicTableScene : public QGraphicsScene
     Q_OBJECT
 
 public:
-    PeriodicTableScene(QObject *parent = 0);
-    ~PeriodicTableScene();
+    explicit PeriodicTableScene(QObject *parent = nullptr);
+    ~PeriodicTableScene() override;
 
 Q_SIGNALS:
     /**
@@ -70,10 +70,10 @@ private:
     QPointF m_eventPos;
 
 protected:
-    bool event(QEvent *e);
-    void mousePressEvent(QGraphicsSceneMouseEvent *event);
-    void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
-    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
+    bool event(QEvent *e) override;
+    void mousePressEvent(QGraphicsSceneMouseEvent *event) override;
+    void mouseMoveEvent(QGraphicsSceneMouseEvent *event) override;
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent *event) override;
 
 };
 
